==> reffi-client-swing-2.1.12-sources.jar: jp/co/fujitsu/reffi/client/swing/db/ConnectorFactory.java <==
/*
 * Copyright (c) 2010, FUJITSU LIMITED
 * All rights reserved.
 * 
 *  Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice, this
 *    list of conditions and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 *    this list of conditions and the following disclaimer in the documentation and/or
 *    other materials provided with the distribution.
 * 
 * 3. Redistributions with modification must carry prominent notices stating that you changed 
 *    the files and the date of any change.
 * 
 * 4. Neither the name of FUJITSU LIMITED nor the names of its contributors may be used
 *    to endorse or promote products derived from this software without specific prior
 *    written permission.
 * 
 * 5. All your rights under this license shall terminate automatically if you fail to
 *    comply  with any of this list of conditions. If your rights under this license terminate,
 *    you agree to cease use and distribution of this software.
 * 
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL
 * THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT
 * OF SUBSTITUTE GOODS OR SERVICES;LOSS OF USE,DATA, OR PROFITS; OR BUSINESS INTERRUPTION) 
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, 
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package jp.co.fujitsu.reffi.client.swing.db;


import jp.co.fujitsu.reffi.client.swing.model.DatabaseCore;

/**
 * <p>[概 要] </p>
 * 
 * <p>[詳 細] </p>
 * 
 * <p>[備 考] </p>
 * 
 * 
 * <p>[環 境] JDK 6.0 Update 11</p>
 * <p>Copyright (c) 2008-2009 FUJITSU Japan All rights reserved.</p>
 * 
 * @author Project Reffi 
 */
public class ConnectorFactory {

	public static String JNDI_CONNECTOR_FQCN = "jp.co.fujitsu.reffi.client.swing.db.JndiConnector";  

	public static String JDBC_CONNECTOR_FQCN = "jp.co.fujitsu.reffi.client.swing.db.JdbcConnector";  

	
	public static Connector getConnector(DatabaseCore dbCore) throws InstantiationException, IllegalAccessException, ClassNotFoundException {
		Connector ret = null;
		
		ret = createConnector(dbCore);
		
		return ret;
	}
	
	private static Connector createConnector(DatabaseCore dbCore) throws InstantiationException, IllegalAccessException, ClassNotFoundException {
		Connector c = null;
		
		if(dbCore.getDatasource() != null) {
			c = (Connector)Class.forName(JNDI_CONNECTOR_FQCN).newInstance();
			c.setDatasource(dbCore.getDatasource());
		}else{
			c = (Connector)Class.forName(JDBC_CONNECTOR_FQCN).newInstance();
			c.setDriverFqcn(dbCore.getDriverFqcn());
			c.setUrl(dbCore.getUrl());
		}
		
		c.setUser(dbCore.getUser());
		c.setPassword(dbCore.getPassword());
		c.setAutoCommit(dbCore.isAutoCommit());
		
		return c;
	}
}

==> reffi-client-swing-2.1.13-sources.jar: jp/co/fujitsu/reffi/client/swing/db/ConnectorFactory.java <==
/*
 * Copyright (c) 2010, FUJITSU LIMITED
 * All rights reserved.
 * 
 *  Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice, this
 *    list of conditions and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 *    this list of conditions and the following disclaimer in the documentation and/or
 *    other materials provided with the distribution.
 * 
 * 3. Redistributions with modification must carry prominent notices stating that you changed 
 *    the files and the date of any change.
 * 
 * 4. Neither the name of FUJITSU LIMITED nor the names of its contributors may be used
 *    to endorse or promote products derived from this software without specific prior
 *    written permission.
 * 
 * 5. All your rights under this license shall terminate automatically if you fail to
 *    comply  with any of this list of conditions. If your rights under this license terminate,
 *    you agree to cease use and distribution of this software.
 * 
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL
 * THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT
 * OF SUBSTITUTE GOODS OR SERVICES;LOSS OF USE,DATA, OR PROFITS; OR BUSINESS INTERRUPTION) 
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, 
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package jp.co.fujitsu.reffi.client.swing.db;


import jp.co.fujitsu.reffi.client.swing.model.DatabaseCore;

/**
 * <p>[概 要] </p>
 * 
 * <p>[詳 細] </p>
 * 
 * <p>[備 考] </p>
 * 
 * 
 * <p>[環 境] JDK 6.0 Update 11</p>
 * <p>Copyright (c) 2008-2009 FUJITSU Japan All rights reserved.</p>
 * 
 * @author Project Reffi 
 */
public class ConnectorFactory {

	public static String DATASOURCE_CONNECTOR_FQCN = "jp.co.fujitsu.reffi.client.swing.db.DataSourceConnector";

	public static String JDBC_CONNECTOR_FQCN = "jp.co.fujitsu.reffi.client.swing.db.JdbcConnector";  

	
	public static Connector getConnector(DatabaseCore dbCore) throws InstantiationException, IllegalAccessException, ClassNotFoundException {
		Connector ret = null;
		
		ret = createConnector(dbCore);
		
		return ret;
	}
	
	private static Connector createConnector(DatabaseCore dbCore) throws InstantiationException, IllegalAccessException, ClassNotFoundException {
		Connector c = null;
		
		if(dbCore.getDatasource() != null) {
			c = (Connector)Class.forName(DATASOURCE_CONNECTOR_FQCN).newInstance();
			c.setDatasource(dbCore.getDatasource());
		}else{
			c = (Connector)Class.forName(JDBC_CONNECTOR_FQCN).newInstance();
			c.setDriverFqcn(dbCore.getDriverFqcn());
			c.setUrl(dbCore.getUrl());
		}
		
		c.setUser(dbCore.getUser());
		c.setPassword(dbCore.getPassword());
		c.setAutoCommit(dbCore.isAutoCommit());
		
		return c;
	}
}
